@@ -178,6 +178,7 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
     # This is the instance of the LLM provider from jupyter-ai to which we forward the request
     # to generate inline completions.
     _llm_provider: Any | None
+    _llm_prefixer: callable = lambda self, x: "wrong"
 
     def __init__(self):
         super().__init__()
@@ -185,7 +186,7 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
         self._connected_apps = []
         self._llm_provider = None
 
-    def reset_history_position(self, _: Buffer):
+    def reset_history_position(self, _: Buffer) -> None:
         self.skip_lines = 0
 
     def disconnect(self) -> None:
@@ -194,7 +195,7 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
             text_insert_event = pt_app.default_buffer.on_text_insert
             text_insert_event.remove_handler(self.reset_history_position)
 
-    def connect(self, pt_app: PromptSession):
+    def connect(self, pt_app: PromptSession) -> None:
         self._connected_apps.append(pt_app)
         # note: `on_text_changed` could be used for a bit different behaviour
         # on character deletion (i.e. resetting history position on backspace)
@@ -386,9 +387,13 @@ class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
         except ModuleNotFoundError:
             jai_models = None
 
+        hm = buffer.history.shell.history_manager
+        prefix = self._llm_prefixer(hm)
+        print(prefix)
+
         request = jai_models.InlineCompletionRequest(
             number=0,
-            prefix=buffer.document.text,
+            prefix=prefix + buffer.document.text,
             suffix="",
             mime="text/x-python",
             stream=True,
@@ -451,15 +456,6 @@ def accept_or_jump_to_end(event: KeyPressEvent):
         nc.end_of_line(event)
 
 
-def _deprected_accept_in_vi_insert_mode(event: KeyPressEvent):
-    """Accept autosuggestion or jump to end of line.
-
-    .. deprecated:: 8.12
-        Use `accept_or_jump_to_end` instead.
-    """
-    return accept_or_jump_to_end(event)
-
-
 def accept(event: KeyPressEvent):
     """Accept autosuggestion"""
     buffer = event.current_buffer
@@ -642,16 +638,3 @@ def swap_autosuggestion_down(event: KeyPressEvent):
         provider=provider,
         direction_method=provider.down,
     )
-
-
-def __getattr__(key):
-    if key == "accept_in_vi_insert_mode":
-        warnings.warn(
-            "`accept_in_vi_insert_mode` is deprecated since IPython 8.12 and "
-            "renamed to `accept_or_jump_to_end`. Please update your configuration "
-            "accordingly",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return _deprected_accept_in_vi_insert_mode
-    raise AttributeError
